"""
Pirate API Wrapper
~~~~~~~~~~~~~~~~~~~

A basic API wrapper for the Pirate API.

:copyright: (c) 2025 Omkaar
:license: MIT, see LICENSE for more details.
"""


__title__ = 'pirate'
__author__ = 'Omkaar'
__license__ = 'MIT'
__copyright__ = 'Copyright 2025 Omkaar'
__version__ = '1.1.0'


from .utils import *
